@@ -1,6 +1,6 @@
 """This module creates the database."""
 import boto3
-from therapy import PREFIX_LOOKUP
+from therapy import PREFIX_LOOKUP, PROHIBITED_SOURCES
 from botocore.exceptions import ClientError
 from boto3.dynamodb.conditions import Key
 from os import environ
@@ -26,7 +26,12 @@ class Database:
             boto_params = {
                 'region_name': region_name
             }
-            if 'THERAPY_NORM_EB_PROD' not in environ:
+            self.endpoint_url = ''
+            if 'THERAPY_NORM_PROD' in environ:
+                environ['DISEASE_NORM_PROD'] = "true"
+            if 'THERAPY_NORM_EB_PROD' in environ:
+                environ['DISEASE_NORM_EB_PROD'] = "true"
+            else:
                 # EB Instance should not have to confirm.
                 # This is used only for using production via CLI
                 if click.confirm("Are you sure you want to use the "
@@ -37,17 +42,18 @@ class Database:
                     sys.exit()
         else:
             if db_url:
-                endpoint_url = db_url
+                self.endpoint_url = db_url
             elif 'THERAPY_NORM_DB_URL' in environ:
-                endpoint_url = environ['THERAPY_NORM_DB_URL']
+                self.endpoint_url = environ['THERAPY_NORM_DB_URL']
             else:
-                endpoint_url = 'http://localhost:8000'
+                self.endpoint_url = 'http://localhost:8000'
             click.echo(f"***Using Therapy Database Endpoint: "
-                       f"{endpoint_url}***")
+                       f"{self.endpoint_url}***")
+            environ['DISEASE_NORM_DB_URL'] = self.endpoint_url
 
             boto_params = {
                 'region_name': region_name,
-                'endpoint_url': endpoint_url
+                'endpoint_url': self.endpoint_url
             }
 
         self.dynamodb = boto3.resource('dynamodb', **boto_params)
@@ -212,8 +218,9 @@ class Database:
 
         :param query: string to match against
         :param str match_type: type of match to look for. Should be one
-            of "alias", "trade_name", "label", or "rx_brand" (use
-            `get_record_by_id` for concept ID lookup)
+            of {"alias", "trade_name", "label", "xref", "associated_with",
+            "rx_brand"} -- use Database.get_record_by_id() for concept ID
+            lookup
         :return: list of matching records. Empty if lookup fails.
         """
         pk = f'{query}##{match_type.lower()}'
@@ -227,11 +234,40 @@ class Database:
                          f"{e.response['Error']['Message']}")
             return []
 
-    def add_record(self, record: Dict, record_type="identity"):
+    def get_ids_for_merge(self) -> List[str]:
+        """Retrieve concept IDs for use in generating normalized records. Only
+        pulls concept IDs for sources in `therapy.ACCEPTED_SOURCES`.
+        :return: List of concept IDs as strings.
+        """
+        last_evaluated_key = None
+        concept_ids = []
+        prohibited_lower = {s.lower() for s in PROHIBITED_SOURCES}
+        params = {
+            'ProjectionExpression': 'concept_id',
+        }
+        while True:
+            if last_evaluated_key:
+                response = self.therapies.scan(
+                    ExclusiveStartKey=last_evaluated_key, **params
+                )
+            else:
+                response = self.therapies.scan(**params)
+            records = response['Items']
+            for record in records:
+                concept_id = record['concept_id']
+                if not any({s for s in prohibited_lower
+                            if concept_id.startswith(s)}):
+                    concept_ids.append(concept_id)
+            last_evaluated_key = response.get('LastEvaluatedKey')
+            if not last_evaluated_key:
+                break
+        return set(concept_ids)
+
+    def add_record(self, record: Dict, record_type: str = "identity"):
         """Add new record to database.
 
         :param Dict record: record to upload
-        :param str record_type: type of record (either 'identity' or 'merger')
+        :param str record_type: type of record, one of {'identity', 'merger'}
         """
         id_prefix = record['concept_id'].split(':')[0].lower()
         record['src_name'] = PREFIX_LOOKUP[id_prefix]
@@ -241,16 +277,26 @@ class Database:
         try:
             self.batch.put_item(Item=record)
         except ClientError as e:
-            logger.error("boto3 client error on add_record for "
-                         f"{record['concept_id']}: "
-                         f"{e.response['Error']['Message']}")
+            if (len((record['label_and_type']).encode('utf-8')) >= 2048) or \
+                    (len((record['concept_id']).encode('utf-8')) >= 1024):
+                logger.info(f"{record['concept_id']}: An error occurred "
+                            "(ValidationException) when calling the "
+                            "BatchWriteItem operation: Hash primary key "
+                            "values must be under 2048 bytes, and range "
+                            "primary key values must be under 1024 "
+                            "bytes.")
+            else:
+                logger.error("boto3 client error on add_record for "
+                             f"{record['concept_id']}: "
+                             f"{e.response['Error']['Message']}")
 
     def add_ref_record(self, term: str, concept_id: str, ref_type: str):
         """Add auxiliary/reference record to database.
 
         :param str term: referent term
         :param str concept_id: concept ID to refer to
-        :param str ref_type: one of ('alias', 'label', 'other_id', 'xref')
+        :param str ref_type: one of {'alias', 'label', 'trade_name',
+            'xref', 'associated_with', 'rx_brand'}
         """
         label_and_type = f'{term.lower()}##{ref_type}'
         src_name = PREFIX_LOOKUP[concept_id.split(':')[0].lower()]
@@ -263,16 +309,27 @@ class Database:
         try:
             self.batch.put_item(Item=record)
         except ClientError as e:
-            logger.error(f"boto3 client error adding reference {term} for "
-                         f"{concept_id} with match type {ref_type}: "
-                         f"{e.response['Error']['Message']}")
+            if (len((record['label_and_type']).encode('utf-8')) >= 2048) or \
+                    (len((record['concept_id']).encode('utf-8')) >= 1024):
+                logger.info(f"{record['concept_id']}: An error occurred "
+                            "(ValidationException) when calling the "
+                            "BatchWriteItem operation: Hash primary key "
+                            "values must be under 2048 bytes, and range "
+                            "primary key values must be under 1024 "
+                            "bytes.")
+            else:
+                logger.error(f"boto3 client error adding reference {term} for "
+                             f"{concept_id} with match type {ref_type}: "
+                             f"{e.response['Error']['Message']}")
 
-    def update_record(self, concept_id: str, field: str, new_value: Any):
+    def update_record(self, concept_id: str, field: str, new_value: Any,
+                      item_type: str = 'identity'):
         """Update the field of an individual record to a new value.
 
         :param str concept_id: record to update
         :param str field: name of field to update
         :param Any new_value: new value
+        :param str item_type: record type, one of {'identity', 'merger'}
         """
         key = {
             'label_and_type': f'{concept_id.lower()}##identity',
