@@ -1,10 +1,10 @@
 """This module provides methods for handling queries."""
 import re
 from typing import List, Dict, Set, Optional
+from .version import __version__
 from therapy import SOURCES, NAMESPACE_LOOKUP, PROHIBITED_SOURCES, \
-    PREFIX_LOOKUP
+    PREFIX_LOOKUP, ITEM_TYPES
 from uvicorn.config import logger
-from therapy import __version__
 from therapy.database import Database
 from therapy.schemas import Drug, SourceMeta, MatchType, ServiceMeta, \
     HasIndication, SourcePriority
@@ -92,14 +92,6 @@ class QueryHandler:
                                                     disease_label=i[1],
                                                     normalized_disease_id=i[2])
                                       for i in inds]
-        set_attrs = ['aliases', 'trade_names', 'xrefs', 'associated_with',
-                     'approval_year', 'has_indication']
-        for attr in set_attrs:
-            if attr not in item.keys():
-                item[attr] = []
-        if 'approval_status' not in item.keys():
-            item['approval_status'] = None
-        item['associated_with'] = item['associated_with']
 
         drug = Drug(**item)
         src_name = item['src_name']
@@ -238,9 +230,7 @@ class QueryHandler:
         if len(sources) == 0:
             return response
 
-        match_types = ['label', 'trade_name', 'alias', 'xref',
-                       'associated_with']
-        for match_type in match_types:
+        for match_type in ITEM_TYPES.values():
             (response, sources) = self._check_match_type(query, response,
                                                          sources, match_type)
             if len(sources) == 0:
@@ -384,7 +374,12 @@ class QueryHandler:
             'extensions': [],
         }
         if 'xrefs' in record:
-            vod['xrefs'] = record['xrefs']
+            xrefs = record['xrefs']
+            chembl_refs = [ref for ref in xrefs if ref.startswith('chembl')]
+            vod['xrefs'] = [ref for ref in xrefs
+                            if not ref.startswith('chembl')]
+        else:
+            chembl_refs = None
         if 'aliases' in record:
             vod['alternate_labels'] = record['aliases']
 
@@ -422,7 +417,10 @@ class QueryHandler:
         for field, name in (('trade_names', 'trade_names'),
                             ('associated_with', 'associated_with')):
             values = record.get(field)
+
             if values:
+                if (field == 'associated_with') and chembl_refs:
+                    values += chembl_refs
                 vod['extensions'].append({
                     'type': 'Extension',
                     'name': name,
@@ -479,7 +477,11 @@ class QueryHandler:
         # check concept ID match
         record = self.db.get_record_by_id(query_str, case_sensitive=False)
         if record and record['src_name'].lower() not in PROHIBITED_SOURCES:
-            merge = self.db.get_record_by_id(record['merge_ref'],
+            merge_ref = record.get('merge_ref')
+            if not merge_ref:
+                return self._add_vod(response, record, query,
+                                     MatchType.CONCEPT_ID)
+            merge = self.db.get_record_by_id(merge_ref,
                                              case_sensitive=False,
                                              merge=True)
             if merge is None:
@@ -490,8 +492,7 @@ class QueryHandler:
                                      MatchType.CONCEPT_ID)
 
         # check other match types
-        for match_type in ['label', 'trade_name', 'alias', 'xref',
-                           'associated_with']:
+        for match_type in ITEM_TYPES.values():
             # get matches list for match tier
             matching_refs = self.db.get_records_by_type(query_str, match_type)
             matching_records = \
@@ -505,19 +506,18 @@ class QueryHandler:
                 record = self.db.get_record_by_id(match['concept_id'], False)
                 if record:
                     merge_ref = record.get('merge_ref')
-                    if merge_ref:
-                        merge = self.db.get_record_by_id(record['merge_ref'],
-                                                         case_sensitive=False,
-                                                         merge=True)
-                        if merge is None:
-                            self._handle_failed_merge_ref(record, response,
-                                                          query_str)
-                        else:
-                            return self._add_vod(response, merge, query,
-                                                 MatchType[match_type.upper()])
+                    if not merge_ref:
+                        return self._add_vod(response, record, query,
+                                             MatchType[match_type.upper()])
+                    merge = self.db.get_record_by_id(record['merge_ref'],
+                                                     case_sensitive=False,
+                                                     merge=True)
+                    if merge is None:
+                        return self._handle_failed_merge_ref(record, response,
+                                                             query_str)
                     else:
-                        logger.error(f'Record {record["label_and_type"]} has'
-                                     f' no merge_ref attribute.')
+                        return self._add_vod(response, merge, query,
+                                             MatchType[match_type.upper()])
 
         if not matching_records:
             response['match_type'] = MatchType.NO_MATCH
