@@ -12,15 +12,13 @@ class Therapy(BaseModel):
 
     label: str
     concept_id: str
-    aliases: Optional[List[str]]
-    other_identifiers: Optional[List[str]]
-    xrefs: Optional[List[str]]
+    aliases: Optional[List[str]] = []
+    xrefs: Optional[List[str]] = []
+    associated_with: Optional[List[str]] = []
 
     class Config:
         """Configure model"""
 
-        orm_mode = True
-
         @staticmethod
         def schema_extra(schema: Dict[str, Any],
                          model: Type['Therapy']) -> None:
@@ -47,17 +45,54 @@ class PhaseEnum(IntEnum):
     approved = 4
 
 
+class HasIndication(BaseModel):
+    """Data regarding FDA indication. Currently specific to HemOnc.org data."""
+
+    disease_id: str
+    disease_label: str
+    normalized_disease_id: Optional[str]
+
+    class Config:
+        """Configure Drug class"""
+
+        @staticmethod
+        def schema_extra(schema: Dict[str, Any],
+                         model: Type['Drug']) -> None:
+            """Configure OpenAPI schema"""
+            if 'title' in schema.keys():
+                schema.pop('title', None)
+            for prop in schema.get('properties', {}).values():
+                prop.pop('title', None)
+            schema['example'] = [
+                {
+                    "disease_id": "hemonc:671",
+                    "disease_label": "Testicular cancer",
+                    "normalized_disease_id": "ncit:C7251"
+                },
+                {
+                    "disease_id": "hemonc:645",
+                    "disease_label": "Ovarian cancer",
+                    "normalized_disease_id": "ncit:C7431"
+                },
+                {
+                    "disease_id": "hemonc:569",
+                    "disease_label": "Bladder cancer",
+                    "normalized_disease_id": "ncit:C9334"
+                }
+            ]
+
+
 class Drug(Therapy):
     """A pharmacologic substance used to treat a medical condition."""
 
-    approval_status: Optional[ApprovalStatus]
-    trade_names: Optional[List[str]]
-    label: Optional[str]
+    approval_status: Optional[ApprovalStatus] = None
+    approval_year: Optional[List[int]] = []
+    has_indication: Optional[List[HasIndication]] = []
+    trade_names: Optional[List[str]] = []
+    label: Optional[str] = None
 
     class Config:
-        """Enables orm_mode"""
-
-        orm_mode = True
+        """Configure Drug class"""
 
         @staticmethod
         def schema_extra(schema: Dict[str, Any],
@@ -68,26 +103,26 @@ class Drug(Therapy):
             for prop in schema.get('properties', {}).values():
                 prop.pop('title', None)
             schema['example'] = {
-                'label': 'CISPLATIN',
-                'concept_identifier': 'chembl:CHEMBL11359',
-                'aliases': [
-                    'Cisplatin',
-                    'Cis-Platinum II',
-                    'Cisplatinum',
-                    'cis-diamminedichloroplatinum(II)',
-                    'CIS-DDP',
-                    'INT-230-6 COMPONENT CISPLATIN',
-                    'INT230-6 COMPONENT CISPLATIN',
-                    'NSC-119875',
-                    'Platinol',
-                    'Platinol-Aq'
+                "label": "CISPLATIN",
+                "concept_id": "chembl:CHEMBL11359",
+                "aliases": [
+                    "Cisplatin",
+                    "Cis-Platinum II",
+                    "Cisplatinum",
+                    "cis-diamminedichloroplatinum(II)",
+                    "CIS-DDP",
+                    "INT-230-6 COMPONENT CISPLATIN",
+                    "INT230-6 COMPONENT CISPLATIN",
+                    "NSC-119875",
+                    "Platinol",
+                    "Platinol-Aq"
                 ],
-                'other_identifiers': [],
-                'trade_name': [
-                    'PLATINOL',
-                    'PLATINOL-AQ',
-                    'CISPLATIN'
-                ]
+                "xrefs": [],
+                "associated_with": None,
+                "approval_status": "approved",
+                "approval_year": [],
+                "has_indication": [],
+                "trade_names": ["PLATINOL", "PLATINOL-AQ", "CISPLATIN"]
             }
 
 
@@ -109,8 +144,8 @@ class MatchType(IntEnum):
     LABEL = 80
     TRADE_NAME = 80
     ALIAS = 60
-    OTHER_ID = 60
     XREF = 60
+    ASSOCIATED_WITH = 60
     FUZZY_MATCH = 20
     NO_MATCH = 0
 
@@ -120,8 +155,10 @@ class SourcePriority(IntEnum):
 
     RXNORM = 1
     NCIT = 2
+    HEMONC = 3
+    DRUGBANK = 4
     CHEMIDPLUS = 5
-    WIKIDATA = 6
+    WIKIDATA = 10
 
 
 class SourceName(str, Enum):
@@ -133,6 +170,7 @@ class SourceName(str, Enum):
     DRUGBANK = "DrugBank"
     CHEMIDPLUS = "ChemIDplus"
     RXNORM = "RxNorm"
+    HEMONC = "HemOnc"
 
 
 class SourceIDAfterNamespace(Enum):
@@ -144,6 +182,7 @@ class SourceIDAfterNamespace(Enum):
     NCIT = "C"
     CHEMIDPLUS = ""
     RXNORM = ""
+    HEMONC = ""
 
 
 class ProhibitedSources(Enum):
@@ -152,7 +191,6 @@ class ProhibitedSources(Enum):
     """
 
     CHEMBL = SourceName.CHEMBL.value
-    DRUGBANK = SourceName.DRUGBANK.value
 
 
 class NamespacePrefix(Enum):
@@ -166,6 +204,7 @@ class NamespacePrefix(Enum):
     RXNORM = "rxcui"
     DRUGBANK = "drugbank"
     WIKIDATA = "wikidata"
+    HEMONC = "hemonc"
     NCIT = "ncit"
     FDA = "fda"
     ISO = "iso"
@@ -181,6 +220,8 @@ class NamespacePrefix(Enum):
     THERAPEUTICTARGETSDB = "ttd"
     IUPHAR = "iuphar"
     GUIDETOPHARMACOLOGY = "gtopdb"
+    INCHIKEY = "inchikey"
+    UNII = "unii"
     ATC = "atc"  # Anatomical Therapeutic Chemical Classification System
     CVX = "cvx"  # Vaccines Administered
     MMSL = "mmsl"  # Multum MediSource Lexicon
@@ -199,6 +240,17 @@ class DataLicenseAttributes(BaseModel):
     attribution: StrictBool
 
 
+class ItemTypes(str, Enum):
+    """Item types used in DynamoDB."""
+
+    # Must be in descending MatchType order.
+    LABEL = 'label'
+    TRADE_NAMES = 'trade_name'
+    ALIASES = 'alias'
+    XREFS = 'xref'
+    ASSOCIATED_WITH = 'associated_with'
+
+
 class SourceMeta(BaseModel):
     """Metadata for a given source to return in response object."""
 
@@ -210,7 +262,7 @@ class SourceMeta(BaseModel):
     data_license_attributes: Dict[str, StrictBool]
 
     class Config:
-        """Enables orm_mode"""
+        """Configure OpenAPI schema"""
 
         @staticmethod
         def schema_extra(schema: Dict[str, Any],
@@ -246,7 +298,7 @@ class MatchesKeyed(BaseModel):
     source_meta_: SourceMeta
 
     class Config:
-        """Enables orm_mode"""
+        """Configure OpenAPI schema"""
 
         @staticmethod
         def schema_extra(schema: Dict[str, Any],
@@ -287,7 +339,7 @@ class MatchesListed(BaseModel):
     source_meta_: SourceMeta
 
     class Config:
-        """Enables orm_mode"""
+        """Configure openAPI schema"""
 
         @staticmethod
         def schema_extra(schema: Dict[str, Any],
@@ -318,21 +370,40 @@ class MatchesListed(BaseModel):
             }
 
 
-class Extension(BaseModel):
-    """Value Object Descriptor Extension class."""
-
-    type: str
-    name: str
-    value: Union[bool, List[str]]
-
-
-class ValueObjectDescriptor(BaseModel):
-    """VOD class. Provide additional Extension classes for trade_names and
-    references to non-normalized sources.
+class DiseaseDescriptor(BaseModel):
+    """VOD class for diseases. Used within the FDAStatus extension in the
+    main therapy VOD.
     """
 
     id: str
-    type: str
+    type = "DiseaseDescriptor"
+    value: Optional[Dict]
+    label: str
+
+
+class FDAStatus(BaseModel):
+    """VOD Extension class for FDA status/indication attributes."""
+
+    approval_status: Optional[ApprovalStatus]
+    approval_year: Optional[List[int]]
+    has_indication: Optional[List[Union[Dict, DiseaseDescriptor]]]
+
+
+class Extension(BaseModel):
+    """Value Object Descriptor Extension class."""
+
+    type = "Extension"
+    name: str
+    value: Union[bool, List[str], FDAStatus]
+
+
+class TherapyDescriptor(BaseModel):
+    """Therapy VOD class. Provide additional Extension classes for trade_names
+    and references to non-normalized sources as well as FDA approval data.
+    """
+
+    id: str
+    type = "TherapyDescriptor"
     value: Any
     label: str
     xrefs: Optional[List[str]]
@@ -349,7 +420,7 @@ class ServiceMeta(BaseModel):
     url: str
 
     class Config:
-        """Enables orm_mode"""
+        """Configure OpenAPI schema"""
 
         @staticmethod
         def schema_extra(schema: Dict[str, Any],
@@ -373,12 +444,12 @@ class NormalizationService(BaseModel):
     query: str
     warnings: Optional[Dict]
     match_type: MatchType
-    value_object_descriptor: Optional[ValueObjectDescriptor]
+    value_object_descriptor: Optional[TherapyDescriptor]
     source_meta_: Optional[Dict[SourceName, SourceMeta]]
     service_meta_: ServiceMeta
 
     class Config:
-        """Enables orm_mode"""
+        """Configure OpenAPI schema"""
 
         @staticmethod
         def schema_extra(schema: Dict[str, Any],
@@ -542,8 +613,8 @@ class SearchService(BaseModel):
                                     "cis-Diaminedichloroplatinum",
                                     "1,2-Diaminocyclohexaneplatinum II citrate"
                                 ],
-                                "other_identifiers": ["drugbank:DB00515"],
-                                "xrefs": ["fda:Q20Q21Q62J"],
+                                "xrefs": ["drugbank:DB00515"],
+                                "associated_with": ["fda:Q20Q21Q62J"],
                                 "approval_status": None,
                                 "trade_names": []
                             }
@@ -584,11 +655,11 @@ class SearchService(BaseModel):
                                     "DDP",
                                     "Diamminodichloride, Platinum"
                                 ],
-                                "other_identifiers": [
+                                "xrefs": [
                                     "drugbank:DB00515",
                                     "drugbank:DB12117"
                                 ],
-                                "xrefs": [
+                                "associated_with": [
                                     "usp:m17910",
                                     "vandf:4018139",
                                     "mesh:D002945",
@@ -626,8 +697,8 @@ class SearchService(BaseModel):
                                 "label": "Cisplatin",
                                 "concept_id": "ncit:C376",
                                 "aliases": [],
-                                "other_identifiers": ["chemidplus:15663-27-1"],
-                                "xrefs": [
+                                "xrefs": ["chemidplus:15663-27-1"],
+                                "associated_with": [
                                     "umls:C0008838",
                                     "fda:Q20Q21Q62J",
                                     "chebi:CHEBI:27899"
@@ -664,13 +735,15 @@ class SearchService(BaseModel):
                                     "CIS-DDP",
                                     "Platinol-AQ"
                                 ],
-                                "other_identifiers": [
+                                "xrefs": [
                                     "chemidplus:15663-27-1",
                                     "chembl:CHEMBL11359",
                                     "rxcui:2555",
                                     "drugbank:DB00515"
                                 ],
-                                "xrefs": ["pubchem.compound:5702198"],
+                                "associated_with": [
+                                    "pubchem.compound:5702198"
+                                ],
                                 "approval_status": None,
                                 "trade_names": []
                             }
